<!--
/* *******************************************************************************
Title:  Non-Adaptive, Linear SNO for within-SCO Navigation
Author:  Edward R. Jones, Ph.D.
Purpose: within-SCO sharable navigation object implementing non-adaptive, linear
         navigation within a SCO
Input:   noAPI - a boolean variable set to true if the SCO is being run outside
           an LMS and set to false if it is being run inside a SCORM-compliant
           LMS
         APIFrame - the location of the frame containing the SCORM-compliant 
           API loaded by the LMS.  For WebMentor the location of this frame 
           is top.API
         contentFrame - the location of the frame used to hold the SCO content
         debugSwitchIsTrue - debug switch for uncovering LMS/SNO problems

Copyright (C) 2001 Edward R. Jones

This program is free software; you can redistribute it and/or modify it under the terms of the SNO License as distributed in the license.txt file included in this
distribution.
/* *******************************************************************************

/*
Set the following variable to true to help debug any problem you might have using this 
SNO with your LMS
*/
var debugSwitchIsTrue = false;   // debug switch to help uncover LMS/SNO communication issues
/* 
Set the following variable to the location of the SCO content frame.  Use the standard
javascript/DOM path.  For this example, the content frame is loaded in the same page as
the SNO.  Hence its location is "parent".
*/

var contentFrame = parent;
/* 
If you are developing a course and would like to test it on your desktop, you 
will need to disable the API calls, since they are designed to interact with
the LMS.  Set the following variable to true, if you would like to run your
SCO outside the LMS.
*/

var noAPI = true;

/*
If you are using the WebMentor LMS, you should not need to change anything in 
the following script. However, a pointer "API" is set below to point to the
frame in which the LMS has loaded the API wrapper.  This variable may
need to be set differently if the template file is changed in WebMentor,
or if you are using a different LMS.

This script is used for within-SCO navigation.  This implements linear
within-SCO navigation, as described in the ADL Guidelines.

Navigation between SCO's is the sole responsibility of the LMS.
In SCORM version 1.2, SCO's are prohibited from using their own
methods to navigate to another SCO, such as the use of links to
the next SCO.This is done to ensure that an SCO can be 
removed from a repository and reaggregated into another course.

Although some Learning Management Systems do not check to ensure that
your SCO's are not linking directly to another SCO, incorporating
between SCO navigation within an SCO would be non-SCORM compliant.
*/

/*
The SCORM 1.2 runtime description indicates that the SCORM runtime environment is
initialized by calling LMSInitialize(""), with an empty string passed bu this function.  
This seems simple enough, but since each LMS is allowed to implement the API Wrapper
supporting the runtime calls in its own fashion, the details of how to conduct this 
call can vary from one LMS to another.

WebMentor, and other LMS's that use javascript to support the API wrapper, place the 
javascript containing the wrapper (contained in a javascript file called api.js) in 
an empty, hidden frame.  To make an SCORM runtime call to the LMS requires the location
of this hidden frame.  A generalized approach to finding this problem is to search 
every frame above the parent of the SCONavFrame.

A more direct approach, which is what is used here, is to find the name of this frame and 
set the following variable (API) to this location.  In WebMentor, the name of this frame
is found in the file "runtime.html" located in the templates folder for the course.

I can also be found by opening the course in WebMentor and looking at the source code.
The bottom of the code will contain a statement similar to this:

<frame NAME="API" src="api.html" border="0" framespacing="0" frameborder="NO" name="Hidden API Frame">

The name of the frame containing the api, for WebMentor, is "API".  Hence, the javascript functions located 
in that frame can be accessed by using the prefix "top.API".  For example, the call to LMSInitialize would
be "top.API.LMSInitialize()".

Of course, if the API wrapper is implemented in CGI or Java, then the specific script required to call 
the LMS runtime functions would be different.  In some cases, it might be as simple as calling a CGI 
with the string containing the runtime call.

In this case, however, this course is being hosted on a WebMentor server, which uses an API wrapper 
implemented in javascript.  Hence, please set the following variable to the frame location for the api in your LMS.
*/

var APIFrame = top.API;          // This is the default location fo the API for WebMentor, this might need to 
                            // be changed for other Learning Management Systems

/* ************************************************************************************** */
/*  There should be no need to change any of the script beyond this point.                */
/* ************************************************************************************** */

/* Initialize within-SCO navigation Tracking Variables. */
var numberOfPages = parent.scoPages.length - 1; // number of pages in the SCO
var SCOInitialized = false;      // this variable is set to true when the sco is initialized
var pageNumber = 1;      // point to current page within an SCO
var currentSCOPage = 1;  // variable used to point to the current page number within an SCO

/*
The following statement sets the contents of the SCOContentFrame to the first page of contents.
This is done here, rather than in the <frame> statement in index.html to make the script
compatible with Netscape 4.x and Netscape 6.x.
*/
contentFrame.SCOContentFrame.location = "../" + parent.scoPages[1];  // set first page of content

/* 
Now Initialize the SCO for the 1st time.  An error here would suggest that the variable
API is not pointing to the frame used by the API to contain the API Wrapper.  The call to
LMSInitialize is just signaling the LMS that communications between the LMS and SCO should
be opened.  A call to LMSInitialize when the SCO is already initialized would be an error.
Hence, in the within-SCO navigation functions, it is important to determine whether the 
SCO is initialized before calling LMSInitialize (or LMSFinish).  The variable SCOInitialized
is used to track this information.
*/
var result = false;
if (!noAPI) {
   result = APIFrame.LMSInitialize("");
   if (!result) { alert("Error:  Unable to find the API Wrapper in the frame " + APIFrame);
   }else{
      SCOInitialized = true;        // this variable tracks the initialized state of the SCO
   }
}

/* Get Browser Name */

function getBrowserName() {

   var lsBrowser = navigator.appName;
   if (lsBrowser.indexOf("Microsoft") >= 0) {
      lsBrowser = "MSIE";
   }else{
      if (lsBrowser.indexOf("Netscape") >= 0) {
            lsBrowser = "Netscape";
         }else{
            lsBrowser = "Unknown";
      }
   }
   return lsBrowser;
}

/* Get Browser Version */

function getBrowserVersion() {
   var findIndex;
   var browserVersion = 0;
   var browser = getBrowserName();

   if (browser == "MSIE") {
      browserVersion = navigator.userAgent;
      findIndex = browserVersion.indexOf(browser) + 5;
      browserVersion = parseInt(browserVersion.substring(findIndex,findIndex+1));
   } else {
      browserVersion = parseInt(navigator.appVersion.substring(0,1));
      if(browserVersion == 5) {browserVersion = 6}
   }
   return browserVersion;
}

/* Get Name of Operating System */
function getOS()
{
   var userPlat = "unknown";
   var navInfo = navigator.userAgent;

   if ((navInfo.indexOf("windows NT") != -1)
       || (navInfo.indexOf("windows 95") != -1 )
       || (navInfo.indexOf("windows 98") != -1 )
       || (navInfo.indexOf("WinNT") != -1 )
       || (navInfo.indexOf("Win95") != -1 )
       || (navInfo.indexOf("Win98") != -1 ))
   {
      userPlat = "Win32";
   }
   else if(navInfo.indexOf("Win16") != -1)
   {
      userPlat = "Win16";
   }
   else if(navInfo.indexOf("Macintosh") != -1)
   {
      userPlat = "PPC";
   }
   else if(navInfo.indexOf("68K") != -1)
   {
      userPlat = "68K";
   }
   return userPlat;
}
/* Function used to jump to the First page in the SCO */
function goToFirstPage () {
   if (!SCOInitialized && !noAPI){
      result = APIFrame.LMSInitialize("");
      if (result) {
         SCOInitialized = true;
         if (debugSwitchIsTrue) {alert("SCO Initialized");}
      }
   }
   if (currentSCOPage != 1) {
      currentSCOPage = 1;
      contentFrame.SCOContentFrame.location =  "../" + parent.scoPages[1];
      firstTimeToFront = true;
   }else{
      alert("This is the 1st Page.  Use Between-SCO Navigation to return to the previous SCO");
   }
}

/* 
Function used to go to the next page in the SCO.  This could be the last page or
an attempt to jump to the next SCO, which is not allowed.  SCO to SCO navigation must
be done using the LMS
*/
function goToNextPage () {
   if(currentSCOPage < numberOfPages){
      currentSCOPage = currentSCOPage + 1;
      if ((currentSCOPage == numberOfPages) && (SCOInitialized) && (!noAPI)) {
         result = APIFrame.Finish();
         if (result) {
            SCOInitialized = false;
            if (debugSwitchIsTrue) {alert("SCO Finished");}
         }else{
               alert("Error:  LMSFinish Call Failed");
         }
      }
      contentFrame.SCOContentFrame.location =  "../" + parent.scoPages[currentSCOPage];
   }else{
      alert("This is the last page.  Use Between-SCO Navigation to go to the next SCO");
   }
}

/* 
Function used to go to the previous page in the SCO, which could be the first page or
an attempt to backup to the previous SCO (which is not allowed)
*/
function goToPreviousPage () {
   if(currentSCOPage !=1){
      currentSCOPage = currentSCOPage - 1;
      if (!SCOInitialized && !noAPI) {
         result = APIFrame.LMSInitialize("");
         if (result) {
            SCOInitialized = true;
            if (debugSwitchIsTrue) {alert("SCO Initialized");}
         }
      }
      contentFrame.SCOContentFrame.location = "../" +  parent.scoPages[currentSCOPage];
   }else{
      alert("This is the 1st Page.  Use Between SCO Navigation to return to the previous SCO");
   }
}

function goToLastPage () {
   if (SCOInitialized && !noAPI){
     result = APIFrame.LMSFinish("");
     if (result) {
         SCOInitialized = false;
         if (debugSwitchIsTrue) {alert("SCO is Finished");}
      }
   }
   if(currentSCOPage != numberOfPages){
      currentSCOPage = numberOfPages;
      contentFrame.SCOContentFrame.location =  "../" + parent.scoPages[currentSCOPage];
   }else{
      alert("This is the last page.  Use Between SCO Navigation to go to the next SCO");
   }
}
-->